library(dnamatch2);sessionInfo()
rm(list=ls())
trafold <- "Tracefiles" 
reffold <- "Reffiles"
freqfile <- "ESX17_Norway.csv" #name of frequency file

#options:
sameCID = TRUE #should comparisons with same Case ids be considered?
betweensamples = FALSE #should comparisons between trace samples be considered?

#Filter settings:
threshHeight = 150 #required detection threshold (alleles with peak heights less are removed)
threshStutt = 0.1 #alleles in stutter position with relative peak heights of 0.1 or less compared to parent alleles are removed
threshMaj = 0.6 #The required relative peak height (at least) to be considered as part of major profile.
minLocStain = 10 #minimum required number non-empty loci for a trace to be considered
minLocMaj = 8 #the minimum number of extracated loci of the major for that to be considered

#Search Settings:
threshMAC = 0.8 #the treshold for candidate list 1: The proportion of alleles of the reference which are contained in a trace sample. Must be between zero and one. 
threshLR = c(10, 100) #the treshold for candidate list 2 and 3: The likelihood ratio thresholds for qualitative and quantiative models (LR>thresh required to be a match candidate).

#Model settings:
kit = "ESX17" #the kitshort name used to model degradation in euroformix.
pC = 0.05 #the dropin probability parameter in the qualitative/quantiative models.
lambda = 0.01 #the model for the dropin peak heights in the quantitative models.

dnamatch2(fn=trafold,freqfile=freqfile, reffold = reffold, sameCID = sameCID, betweensamples = betweensamples, 
    threshMAC = threshMAC, threshLR = threshLR, threshHeight = threshHeight, 
    threshStutt = threshStutt, threshMaj = threshMaj, minLocStain = minLocStain, minLocMaj = minLocMaj, 
    pC = pC, lambda = lambda, kit = kit, timediff = timediff, 
    printHistPlots = TRUE) 

#Show matches in a graph:
library(igraph)
tab <- read.table(file=paste0("matchfile.csv"),header=TRUE,sep=";",stringsAsFactors=FALSE)
fra <- tab$refID
til <- tab$tarID 
rem <- duplicated(cbind(fra,til)) #indices to remove
rels <- data.frame(from=fra[!rem],to=til[!rem],weight=sqrt(log10(as.numeric(tab$LRquan[!rem]))))
gg <- graph.data.frame(rels,directed=FALSE)
plot(gg,edge.width=E(gg)$weight,vertex.color="white",vertex.size=10,vertex.label.color="black",vertex.label.cex=0.8)



